@@ -1,25 +1,32 @@
 import asyncio
+from bergen.wards.graphql.aiohttp import AIOHttpGraphQLWard
 from bergen.enums import ClientType
-from bergen.wards.graphql.subscription import SubscriptionGraphQLWard
 from bergen.logging import setLogging
 from bergen.auths.base import BaseAuthBackend
 from bergen.wards.base import BaseWard
 from bergen.postmans.base import BasePostman
 import logging
-
+from threading import Thread
 logger = logging.getLogger(__name__)
 import os
 
+def start_background_loop(loop: asyncio.AbstractEventLoop) -> None:
+    asyncio.set_event_loop(loop)
 
 class BaseBergen:
 
 
-    def __init__(self, auth: BaseAuthBackend, host: str, port: int, protocol = "http", auto_negotiate=True, bind=True, log=logging.INFO, local=None, loop=None,  client_type: ClientType = None, **kwargs) -> None:
+    def __init__(self, auth: BaseAuthBackend, host: str, port: int, protocol = "http", auto_negotiate=True, bind=True, log=logging.INFO, local=None, loop=None,  client_type: ClientType = None, jupyter=False, force_sync = False, **kwargs) -> None:
         
+        self.running_in_sync = jupyter or force_sync
+        
+
         try:
-            self.loop = loop or asyncio.get_running_loop()
-            self.loop_is_running = True
-            logger.info("Using provided Async Loop")
+            self.loop = asyncio.get_running_loop()
+            if self.running_in_sync:
+                import nest_asyncio
+                nest_asyncio.apply(self.loop)
+
         except RuntimeError:
             self.loop = asyncio.get_event_loop()
             self.loop_is_running = False
@@ -50,57 +57,57 @@ class BaseBergen:
         self.token = self.auth.getToken()
         logger.info(" Auhorized!!!!!")
 
-        self.main_ward = SubscriptionGraphQLWard(host=host, port=port, protocol=protocol, token=self.token, loop=self.loop)
+        self.host = host
+        self.port = port
+        self.protocol = protocol
 
         self._transcript = None
         self.identifierDataPointMap = {}
         self.identifierWardMap: dict[str, BaseWard] = {}
 
 
-        if auto_negotiate == True and not self.loop_is_running: # If we are running in a loop we shouldn't negotiate
-            self.negotiate()
+        if auto_negotiate == True:
+            if self.loop.is_running() and not self.running_in_sync: 
+                pass
+            else:
+               self.negotiate()
+
+
+        super().__init__() 
+
+    def getLoopAndContext(self):
+        return self.loop, self.running_in_sync    
 
-        super().__init__()
-            
 
     @property
     def transcript(self):
         assert self._transcript is not None, "We have to negotiate first with our"
         return self._transcript
 
-
     def getExtensionSettings(self, extension):
         assert extension in self.transcript.extensions, f"Arnheim seems to have no idea about this Extension {extension}"
         return self.transcript.extensions[extension]
 
-
     def getWardForIdentifier(self, identifier):
-        assert self._transcript is not None, "We cannot get query Identifiers on Datapoint before having negotiated them"
+        if self._transcript is None:
+            if self.running_in_sync:
+                raise Exception("Not negotiated Error: Please negotiate first or set auto_negotiate=True")
+            else:
+                raise Exception("You are running in event Loop: Please await self.negotiate_async first or run with 'async with Bergen(....)'")
+
         if identifier in self.identifierWardMap:
             return self.identifierWardMap[identifier]
         else:
             return self.main_ward
 
 
-    def registerDatapoints(self, transcript):
-        assert transcript.models is not None, "We apparently didnt't get any points"
-        
-        from bergen.registries.datapoint import get_datapoint_registry
-        datapoint_registry = get_datapoint_registry()
-
-        self.identifierDataPointMap = {model.identifier.lower(): model.point for model in transcript.models}
-        self.identifierWardMap = {model.identifier.lower(): datapoint_registry.getClientForData(model.point, self.auth) for model in transcript.models}
-        logger.info("Succesfully registered Datapoints") 
-
-
-
-    def setPostmanFromSettings(self, transcript):
+    def getPostmanFromSettings(self, transcript):
         settings = transcript.postman
 
         if settings.type == "pika":
             try:
                 from bergen.postmans.pika import PikaPostman
-                self.postman = PikaPostman(**settings.kwargs, loop=self.loop)
+                postman = PikaPostman(**settings.kwargs, loop=self.loop)
             except ImportError as e:
                 logger.error("You cannot use the Pika Postman without installing aio_pika")
                 raise e
@@ -108,7 +115,7 @@ class BaseBergen:
         elif settings.type == "websocket":
             try:
                 from bergen.postmans.websocket import WebsocketPostman
-                self.postman = WebsocketPostman(**settings.kwargs, loop=self.loop)
+                postman = WebsocketPostman(**settings.kwargs, loop=self.loop)
             except ImportError as e:
                 logger.error("You cannot use the Websocket Postman without installing websockets")
                 raise e
@@ -116,49 +123,46 @@ class BaseBergen:
         else:
             raise Exception(f"Postman couldn't be configured. No Postman for type {settings.type}")
 
-        return self.postman
+        return postman
 
     
     async def negotiate_async(self, client_type=None):
         from bergen.constants import NEGOTIATION_GQL
-        
+        from bergen.registries.datapoint import get_datapoint_registry
+
+        # Instantiate our Main Ward, this is only for Nodes and Pods
+        self.main_ward = AIOHttpGraphQLWard(host=self.host, port=self.port, protocol=self.protocol, token=self.token, loop=self.loop)
+        await self.main_ward.configure()
+
         # We resort escalating to the different client Type protocols
         clientType = client_type or self.client_type or self.auth.getClientType()
         self._transcript = await NEGOTIATION_GQL.run_async(ward=self.main_ward, variables={"clientType": clientType, "local": self.local})
-        self.registerTranscript(self._transcript)
+        
 
-        postman = self.setPostmanFromSettings(self._transcript)
-        await postman.configure()
+        #Lets create our different Wards 
+        
+        assert self._transcript.models is not None, "We apparently didnt't get any points"
+        
+        datapoint_registry = get_datapoint_registry()
+
+
+        self.identifierDataPointMap = {model.identifier.lower(): model.point for model in self._transcript.models}
+        self.identifierWardMap = {model.identifier.lower(): datapoint_registry.createWardForDatapoint(model.point, self) for model in self._transcript.models}
+
+        logger.info("Succesfully registered Datapoints") 
+        await datapoint_registry.configureWards()
+        logger.info("Succesfully connected to Datapoints") 
+
+
+        self.postman = self.getPostmanFromSettings(self._transcript)
+        await self.postman.configure()
 
     async def disconnect_async(self, client_type=None):
         await self.postman.disconnect()
 
-
-
-    def registerTranscript(self, transcript):
-        logger.info(f"Successfully Got Protocols")
-
-        if self._transcript:
-            self.registerDatapoints(self._transcript)
-
-        logger.info("We established all Proper Clients for the interaction!")
-        logger.info("Arnheim Ready!!!!!!!!")
-
-
-
     def negotiate(self, client_type = None):
-        from bergen.constants import NEGOTIATION_GQL
+        self.loop.run_until_complete(self.negotiate_async())
         
-        # We resort escalating to the different client Type protocols
-        clientType = client_type or self.client_type or self.auth.getClientType()
-        self._transcript = NEGOTIATION_GQL.run(ward=self.main_ward, variables={"clientType": clientType or self.auth.getClientType(), "local": self.local})
-        self.registerTranscript(self._transcript)
-
-        postman = self.setPostmanFromSettings(self._transcript)
-        self.loop.run_until_complete(postman.configure())
-        
-
-
     def getWard(self) -> BaseWard:
         return self.main_ward
 
@@ -166,6 +170,7 @@ class BaseBergen:
         return self.postman
 
     def _repr_html_(self):
+        if not self._transcript: return """Unconnected Client"""
         return f"""
             <p> Arnheim Client <p>
             <table>
@@ -174,11 +179,8 @@ class BaseBergen:
                 </tr>
             </table>
 
-
-
         """
 
-
     async def __aenter__(self):
         await self.negotiate_async()
         print(self)
