@@ -1,6 +1,7 @@
 
 
 from abc import ABC, abstractmethod
+from re import template
 from bergen.messages.allowance import AllowanceMessage
 from typing import Union
 from bergen.utils import ExpansionError, expandInputs
@@ -79,7 +80,11 @@ class WebsocketPeasent(BasePeasent):
 
 
     async def connect_websocket(self):
-        uri = f"{self.websocket_protocol}://{self.websocket_host}:{self.websocket_port}/peasent/{self.unique_name}/?token={self.token}"
+
+        hosted_templates = [str(templateid) for templateid, function in self.templateid_template_map.items()]
+        hosted_templates_qstring = ",".join(hosted_templates)
+
+        uri = f"{self.websocket_protocol}://{self.websocket_host}:{self.websocket_port}/peasent/{self.unique_name}/?token={self.token}&templates={hosted_templates_qstring}"
         try:
             self.connection = await websockets.client.connect(uri)
 
