@@ -7,11 +7,9 @@ from bergen.messages.base import MessageModel
 from bergen.messages.assignation_request import AssignationRequestMessage
 from bergen.postmans.base import BasePostman
 from aiostream import stream
-import aiormq
 import json
 import uuid
 import logging
-from aio_pika.patterns import RPC
 import asyncio
 import websockets
 import sys
@@ -34,8 +32,8 @@ class WebsocketPostman(BasePostman):
         self.port = port
         self.protocol = protocol
         self.host = host
-        self.connection = None      # type: aiormq.Connection
-        self.channel = None         # type: aiormq.Channel
+        self.connection = None      
+        self.channel = None         
         self.callback_queue = ''
         self.futures = {}
 
