@@ -1,10 +1,10 @@
-from bergen.registries.arnheim import get_current_arnheim
-from bergen.wards.graphql.default import GraphQlWard
+from bergen.wards.graphql.aiohttp import AIOHttpGraphQLWard
 from bergen.auths.base import BaseAuthBackend
 from typing import Callable
 from bergen.enums import DataPointType
 from bergen.clients.base import BaseWard
 import logging
+import asyncio
 
 logger = logging.getLogger(__name__)
 
@@ -17,13 +17,13 @@ class DataPointRegistry(object):
         self.pointNameWardMap: dict[str, BaseWard] = {}
         self.builders =  {
                 # Default Builders for standard
-                DataPointType.GRAPHQL: lambda datapoint, auth: GraphQlWard(host=datapoint.host, port=datapoint.port, token=auth.getToken(), protocol=auth.getProtocol(), loop=get_current_arnheim().loop)
+                DataPointType.GRAPHQL: lambda datapoint, bergen: AIOHttpGraphQLWard(host=datapoint.host, port=datapoint.port, token=bergen.auth.getToken(), protocol=bergen.auth.getProtocol(), loop=bergen.loop)
         }
 
     def registerClientBuilder(self, type:str , builder: Callable):
         self.builders[type] = builder
 
-    def getClientForData(self,point, auth: BaseAuthBackend) -> BaseWard:
+    def getClientForData(self, point, auth: BaseAuthBackend) -> BaseWard:
         if point.name in self.pointNameWardMap:
             return self.pointNameWardMap[point.name]
 
@@ -36,6 +36,22 @@ class DataPointRegistry(object):
         else:
             raise NotImplementedError("We have no idea how to build that datatype")
 
+    def createWardForDatapoint(self, point, bergen) -> BaseWard:
+        if point.name in self.pointNameWardMap:
+            return self.pointNameWardMap[point.name]
+
+        logger.info(f"Creating new Ward for Datapoint {point}")
+
+        if point.type in self.builders:
+            builder = self.builders[point.type]
+            self.pointNameWardMap[point.name]  = builder(point, bergen)
+            return self.pointNameWardMap[point.name]
+        else:
+            raise NotImplementedError(f"We have no idea how to build the ward for this Datapoint {point.type}")
+
+    async def configureWards(self):
+        wards = [ward for point, ward in self.pointNameWardMap.items()]
+        await asyncio.gather(*[ward.configure() for ward in wards])
 
 
 
