@@ -15,6 +15,14 @@ except ImportError:
 User = ForwardRef("User")
 DataModel = ForwardRef("DataModel")
 
+
+
+class AssignationParams(ArnheimObject):
+    provider: Optional[str]
+
+
+
+
 class Avatar(ArnheimObject):
     user: Optional['User']
     avatar: Optional[str]
@@ -50,9 +58,15 @@ class DataModel(ArnheimModel):
         identifier = "datamodel"
 
 
+class PostmanArgs(ArnheimObject):
+    type: Optional[str]
+    kwargs: Optional[dict]
+
+
 class Transcript(ArnheimObject):
     array: Optional[Any]
     extensions: Optional[Any]
+    postman: Optional[PostmanArgs]
     models: Optional[List[DataModel]]
     points: Optional[List[DataPoint]]
     user: Optional[User]
@@ -76,8 +90,23 @@ class Node(ArnheimModel):
         identifier = "node"
 
 
+
+class ArnheimApplication(ArnheimModel):
+    logo: Optional[str]
+
+    class Meta:
+        identifier = "arnheim_application"
+
+
+class Peasent(ArnheimModel):
+    name: Optional[str]
+    application: Optional[ArnheimApplication]
+
+    class Meta:
+        identifier = "peasent"
+
+
 class Volunteer(ArnheimModel):
-    id: int
     identifier: str
     node: Node
 
@@ -92,9 +121,16 @@ class Template(ArnheimModel):
         get = TEMPLATE_GET_QUERY
 
 
+class PeasentTemplate(Template):
+
+    class Meta:
+        identifier = "peasenttemplate"
+
+
+
+
 class Pod(ArnheimModel):
     template: Optional[Template]
-    id: int
     status: Optional[str]
 
     class Meta:
@@ -117,6 +153,7 @@ class AssignationStatus(str, Enum):
     PROGRESS = "PROGRESS"
     DEBUG = "DEBUG"
     DONE = "DONE"
+    YIELD = "YIELD"
     CRITICAL ="CRITICAL"
     PENDING = "PENDING"
 
